==> kwave_0.7.10.orig.tar.gz: kwave-0.7.10/libgui/MultiStateWidget.h <==
/***************************************************************************
  MultiStateWidget.h  -  provides methods of multistateWidget a Class that
                         switches the image it, displays on clicking, used
                         for the channel enable/disable lamps...
			     -------------------
    begin                : Sun Jun 04 2000
    copyright            : (C) 2000 by Martin Wilz
    email                : martin@wilz.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef _MULTI_STATE_WIDGET_H_
#define _MULTI_STATE_WIDGET_H_

#include "config.h"
#include <qwidget.h>
#include <qpainter.h>

class QString;

class MultiStateWidget : public QWidget
{
    Q_OBJECT

public:

    /** Constructor */
    MultiStateWidget(QWidget *parent = 0, int = 0, int = 2);

    /** Destructor */
    virtual ~MultiStateWidget ();

    /**
     * Sets the number that will passed as argument to the
     * "clicked" signal.
     */
    void setNumber(int number);

    /**
     * Adds a the content of pixmap file as pixmap for the
     * next state. The file is found through the KStandardDirs
     * mechanism. Adding a file for a second or further time
     * is not possible, in this case the pixmap will not be
     * loaded and the return value will be the id of the
     * existing version.
     * @see KStandardDirs
     * @param filename name of the file to be added, without
     *        path.
     * @return id of the corresponding state or -1 if
     *         something went wrong
     */
    int addPixmap(const QString &filename);

    void setStates (int *newstates);
    void setState (int newstate);
    void nextState ();
signals:

    /**
     * Signals that the widget has changed it's state.
     * @param number identifier of this widget's instance
     */
    void clicked(int number);

public slots:

protected:

    void mouseReleaseEvent(QMouseEvent * );
    void paintEvent(QPaintEvent *);

private:

    QPainter p;
    int *states;     // maps states to pixmap-list
    int act;         // current states
    int count;       // number of states
    int number;      // number of channels this object represents... used for signals
}
;

#endif  // _MULTI_STATE_WIDGET_H_

==> kwave_0.8.0.orig.tar.gz: kwave-0.8.0.orig/libgui/MultiStateWidget.h <==
/***************************************************************************
  MultiStateWidget.h  -  provides methods of multistateWidget a Class that
                         switches the image it, displays on clicking, used
                         for the channel enable/disable lamps...
			     -------------------
    begin                : Sun Jun 04 2000
    copyright            : (C) 2000 by Martin Wilz
    email                : martin@wilz.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef _MULTI_STATE_WIDGET_H_
#define _MULTI_STATE_WIDGET_H_

#include "config.h"

#include <QPixmap>
#include <QVector>
#include <QWidget>

#include <kdemacros.h>

class QPaintEvent;
class QMouseEvent;
class QString;

class KDE_EXPORT MultiStateWidget : public QWidget
{
    Q_OBJECT

public:

    /**
     * Constructor
     * @param parent the parent widget
     * @param id identifier
     */
    MultiStateWidget(QWidget *parent, int id);

    /** Destructor */
    virtual ~MultiStateWidget();

    /**
     * Sets the number that will passed as argument to the
     * "clicked" signal.
     * @param id new identifier
     */
    void setID(int id);

    /**
     * Adds a the content of pixmap file as pixmap for the
     * next state. The file is found through the KStandardDirs
     * mechanism. Adding a file for a second or further time
     * is not possible, in this case the pixmap will not be
     * loaded and the return value will be the id of the
     * existing version.
     * @see KStandardDirs
     * @param filename name of the file to be added, without
     *        path.
     */
    void addPixmap(const QString &filename);

    /**
     * Activates a new state, with wrap-around on overflows, limited
     * to [ 0 ... m_pixmaps.count()-1 ].
     * @param state index of the new state [0...N]
     */
    void setState(int newstate);

    /** advance to the next state, with wrap-around to zero */
    void nextState();

signals:

    /**
     * Signals that the widget has changed it's state.
     * @param id identifier of this widget's instance
     */
    void clicked(int id);

private:

    /** reacts to the mouse release (click) */
    virtual void mouseReleaseEvent(QMouseEvent *);

    /** repaints the pixmap */
    virtual void paintEvent(QPaintEvent *);

private:

    /** index of the current state */
    int m_current_index;

    /** identifier used for the clicked() signal */
    int m_identifier;

    /** list of QPixmaps */
    QVector<QPixmap> m_pixmaps;
};

#endif  // _MULTI_STATE_WIDGET_H_
